@@ -55,7 +55,7 @@ if LINUX:
 
 
 # =====================================================================
-# utils
+# --- utils
 # =====================================================================
 
 
@@ -141,7 +141,7 @@ def get_free_version_info():
 
 
 # =====================================================================
-# system virtual memory
+# --- system virtual memory
 # =====================================================================
 
 
@@ -375,7 +375,7 @@ class TestSystemVirtualMemory(unittest.TestCase):
 
 
 # =====================================================================
-# system swap memory
+# --- system swap memory
 # =====================================================================
 
 
@@ -437,7 +437,7 @@ class TestSystemSwapMemory(unittest.TestCase):
 
 
 # =====================================================================
-# system CPU
+# --- system CPU
 # =====================================================================
 
 
@@ -467,8 +467,9 @@ class TestSystemCPU(unittest.TestCase):
     def test_cpu_count_logical_w_sysdev_cpu_online(self):
         with open("/sys/devices/system/cpu/online") as f:
             value = f.read().strip()
-        value = int(value.split('-')[1]) + 1
-        self.assertEqual(psutil.cpu_count(), value)
+        if "-" in str(value):
+            value = int(value.split('-')[1]) + 1
+            self.assertEqual(psutil.cpu_count(), value)
 
     @unittest.skipUnless(os.path.exists("/sys/devices/system/cpu"),
                          "/sys/devices/system/cpu does not exist")
@@ -537,7 +538,7 @@ class TestSystemCPU(unittest.TestCase):
 
 
 # =====================================================================
-# system CPU stats
+# --- system CPU stats
 # =====================================================================
 
 
@@ -558,7 +559,7 @@ class TestSystemCPUStats(unittest.TestCase):
 
 
 # =====================================================================
-# system network
+# --- system network
 # =====================================================================
 
 
@@ -670,7 +671,7 @@ class TestSystemNetwork(unittest.TestCase):
 
 
 # =====================================================================
-# system disk
+# --- system disk
 # =====================================================================
 
 
@@ -828,7 +829,7 @@ class TestSystemDisks(unittest.TestCase):
 
 
 # =====================================================================
-# misc
+# --- misc
 # =====================================================================
 
 
@@ -1019,6 +1020,11 @@ class TestMisc(unittest.TestCase):
             t.stop()
 
 
+# =====================================================================
+# --- sensors
+# =====================================================================
+
+
 @unittest.skipUnless(LINUX, "LINUX only")
 @unittest.skipUnless(hasattr(psutil, "sensors_battery") and
                      psutil.sensors_battery() is not None,
@@ -1035,6 +1041,8 @@ class TestSensorsBattery(unittest.TestCase):
     @unittest.skipUnless(which("acpi"), "acpi utility not available")
     def test_power_plugged(self):
         out = sh("acpi -b")
+        if 'unknown' in out.lower():
+            return unittest.skip("acpi output not reliable")
         plugged = "Charging" in out.split('\n')[0]
         self.assertEqual(psutil.sensors_battery().power_plugged, plugged)
 
@@ -1059,6 +1067,8 @@ class TestSensorsBattery(unittest.TestCase):
         def open_mock(name, *args, **kwargs):
             if name.startswith("/sys/class/power_supply/AC0/online"):
                 return io.BytesIO(b"0")
+            elif name.startswith("/sys/class/power_supply/BAT0/status"):
+                return io.BytesIO(b"discharging")
             else:
                 return orig_open(name, *args, **kwargs)
 
@@ -1072,15 +1082,18 @@ class TestSensorsBattery(unittest.TestCase):
         # Pretend we can't know whether the AC power cable not
         # connected (assert fallback to False).
         def open_mock(name, *args, **kwargs):
-            if name.startswith("/sys/class/power_supply/AC0/online"):
+            if name.startswith("/sys/class/power_supply/AC0/online") or \
+                    name.startswith("/sys/class/power_supply/AC/online"):
                 raise IOError(errno.ENOENT, "")
+            elif name.startswith("/sys/class/power_supply/BAT0/status"):
+                return io.BytesIO(b"???")
             else:
                 return orig_open(name, *args, **kwargs)
 
         orig_open = open
         patch_point = 'builtins.open' if PY3 else '__builtin__.open'
         with mock.patch(patch_point, side_effect=open_mock) as m:
-            self.assertEqual(psutil.sensors_battery().power_plugged, False)
+            self.assertIsNone(psutil.sensors_battery().power_plugged)
             assert m.called
 
     def test_emulate_no_base_files(self):
@@ -1146,21 +1159,23 @@ class TestSensorsBattery(unittest.TestCase):
 
     def test_emulate_no_power(self):
         # Emulate a case where /AC0/online file nor /BAT0/status exist.
-        def path_exists_mock(name):
-            if name.startswith("/sys/class/power_supply/AC0/online") or \
+        def open_mock(name, *args, **kwargs):
+            if name.startswith("/sys/class/power_supply/AC/online") or \
+                    name.startswith("/sys/class/power_supply/AC0/online") or \
                     name.startswith("/sys/class/power_supply/BAT0/status"):
-                return False
+                raise IOError(errno.ENOENT, "")
             else:
-                return orig_path_exists(name)
+                return orig_open(name, *args, **kwargs)
 
-        orig_path_exists = os.path.exists
-        with mock.patch("psutil._pslinux.os.path.exists",
-                        side_effect=path_exists_mock) as m:
+        orig_open = open
+        patch_point = 'builtins.open' if PY3 else '__builtin__.open'
+        with mock.patch(patch_point, side_effect=open_mock) as m:
             self.assertIsNone(psutil.sensors_battery().power_plugged)
             assert m.called
 
+
 # =====================================================================
-# test process
+# --- test process
 # =====================================================================
 
 
@@ -1280,13 +1295,6 @@ class TestProcess(unittest.TestCase):
             p.cmdline() == ['foo', 'bar', '']
             assert m.called
 
-    def test_io_counters_mocked(self):
-        with mock.patch('psutil._pslinux.open', create=True) as m:
-            self.assertRaises(
-                NotImplementedError,
-                psutil._pslinux.Process(os.getpid()).io_counters)
-            assert m.called
-
     def test_readlink_path_deleted_mocked(self):
         with mock.patch('psutil._pslinux.os.readlink',
                         return_value='/home/foo (deleted)'):
@@ -1407,14 +1415,19 @@ class TestProcessAgainstStatus(unittest.TestCase):
 
     def test_cpu_affinity(self):
         value = self.read_status_file("Cpus_allowed_list:")
-        min_, max_ = map(int, value.split('-'))
-        self.assertEqual(
-            self.proc.cpu_affinity(), list(range(min_, max_ + 1)))
+        if '-' in str(value):
+            min_, max_ = map(int, value.split('-'))
+            self.assertEqual(
+                self.proc.cpu_affinity(), list(range(min_, max_ + 1)))
 
     def test_cpu_affinity_eligible_cpus(self):
+        value = self.read_status_file("Cpus_allowed_list:")
         with mock.patch("psutil._pslinux.per_cpu_times") as m:
             self.proc._proc._get_eligible_cpus()
-        assert not m.called
+        if '-' in str(value):
+            assert not m.called
+        else:
+            assert m.called
 
 
 if __name__ == '__main__':
